﻿using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Drawing;
using ThinkGeo.MapSuite.Core;

namespace Post9995
{
    public static class AppExtension
    {
        public static void GenerateCacheFiles(this IEnumerable<Layer> layers, double scale, RectangleShape restrictedExtent, GeographyUnit mapUnit, string cacheDirectory, string cacheId)
        {
            // create a MapSuite default tile matrix object.
            MapSuiteTileMatrix matrix = new MapSuiteTileMatrix(scale, 256, 256, mapUnit);

            // get cells in the specified extent.
            Collection<TileMatrixCell> cells = matrix.GetIntersectingCells(restrictedExtent);

            // create a tile cache object with the cache directory and cache id.
            FileBitmapTileCache tileCache = new FileBitmapTileCache(cacheDirectory, cacheId);
            tileCache.TileMatrix.BoundingBoxUnit = mapUnit;

            foreach (TileMatrixCell cell in cells)
            {
                // create a bitmap whoes size equals to the tile size.
                using (Bitmap bitmap = new Bitmap(256, 256))
                {
                    // create a GeoCanvas which for drawing the passed layers.
                    GdiPlusGeoCanvas geoCanvas = new GdiPlusGeoCanvas();
                    geoCanvas.BeginDrawing(bitmap, cell.BoundingBox, mapUnit);
                    foreach (Layer layer in layers)
                    {
                        lock (layer)
                        {
                            if (!layer.IsOpen) { layer.Open(); }
                            layer.Draw(geoCanvas, new Collection<SimpleCandidate>());
                        }
                    }

                    // you can commend this line out because it's just for mark a cache label in order to see if it works with our samples.
                    geoCanvas.DrawText("Cache", new GeoFont("Arial", 12), new GeoSolidBrush(GeoColor.SimpleColors.Red), new Collection<ScreenPointF>() { new ScreenPointF(128f, 128f) }, DrawingLevel.LabelLevel);
                    geoCanvas.EndDrawing();

                    // create tile object to maintain current tile information.
                    BitmapTile tile = new BitmapTile(bitmap, cell.BoundingBox, scale);

                    // save tile.
                    tileCache.SaveTile(tile);
                }
            }
        }
    }
}
