﻿using System.Collections.ObjectModel;
using System.Windows;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace Post9995
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private static readonly string cacheID = "MajorCities";
        private static readonly string cacheDir = "D:\\CacheTest";

        public MainWindow()
        {
            InitializeComponent();
        }

        private void WpfMap_Loaded(object sender, RoutedEventArgs e)
        {
            Map1.MapUnit = GeographyUnit.Meter;

            WorldMapKitWmsWpfOverlay worldOverlay = new WorldMapKitWmsWpfOverlay();
            worldOverlay.Projection = WorldMapKitProjection.SphericalMercator;
            Map1.Overlays.Add("WMK", worldOverlay);

            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(@"..\..\App_Data\MajorCities.shp");
            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.City1;
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            ManagedProj4Projection proj4 = new ManagedProj4Projection();
            proj4.InternalProjectionParametersString = ManagedProj4Projection.GetEpsgParametersString(4326);
            proj4.ExternalProjectionParametersString = ManagedProj4Projection.GetGoogleMapParametersString();
            worldLayer.FeatureSource.Projection = proj4;

            worldLayer.Open();
            RectangleShape initExtent = worldLayer.GetBoundingBox();
            Map1.CurrentExtent = initExtent;

            LayerOverlay layerOverlay = new LayerOverlay() { TileCache = new FileBitmapTileCache(cacheDir, cacheID) };
            layerOverlay.Layers.Add(worldLayer);
            Map1.Overlays.Add(layerOverlay);

            layerOverlay.Layers.GenerateCacheFiles(Map1.CurrentScale, initExtent, Map1.MapUnit, cacheDir, cacheID);
            Map1.Refresh();
        }
    }
}
